| package |
package := Package name: 'ObjectTree'.
package paxVersion: 0;
	basicComment: ''.

package basicPackageVersion: ''.

"Add the package scripts"

"Add the class names, loose method names, global names, resource names"
package classNames
	add: #ObjectTreeModel;
	add: #ObjectTreeModelPresenter;
	add: #ObjectTreeModelShell;
	add: #ObjectTreeNode;
	yourself.

package methodNames
	add: #Object -> #explore;
	yourself.

package globalNames
	yourself.

package resourceNames
	yourself.

"Binary Global Names"
package binaryGlobalNames: (Set new
	yourself).
"Resource Names"
package allResourceNames: (Set new
	add: #ObjectTreeModelPresenter -> 'Default view';
	add: #ObjectTreeModelShell -> 'Default view';
	yourself).

"Add the prerequisite names"
package setPrerequisites: (IdentitySet new
	add: 'Development System';
	add: 'Dolphin';
	yourself).

package!

"Class Definitions"!

Object subclass: #ObjectTreeNode
	instanceVariableNames: 'descripcion objeto'
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: ''!
VirtualTreeModel subclass: #ObjectTreeModel
	instanceVariableNames: 'objects'
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: ''!
CompositePresenter subclass: #ObjectTreeModelPresenter
	instanceVariableNames: 'tree inspector'
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: ''!
Shell subclass: #ObjectTreeModelShell
	instanceVariableNames: 'objectTreePresenter'
	classVariableNames: ''
	poolDictionaries: ''
	classInstanceVariableNames: ''!
"Loose Methods"!

!Object methodsFor!

explore



	^ObjectTreeModelShell showOn: self! !
!Object categoriesFor: #explore!*-unclassified!public! !

"End of package definition"!



ObjectTreeNode comment: ''!

ObjectTreeNode guid: (GUID fromString: '{26AF8D81-AD4B-11D6-B8E2-000021FB21B2}')!

!ObjectTreeNode categoriesForClass!Unclassified! !
!ObjectTreeNode methodsFor!

descripcion
	"Private - Answer the value of the receiver's ''descripcion'' instance variable."

	^descripcion!

descripcion: anObject
	"Private - Set the value of the receiver's ''descripcion'' instance variable to the argument, anObject."

	descripcion := anObject!

displayOn: aStream


	aStream nextPutAll: descripcion;
		     nextPutAll: ': ' ; 
		      print: objeto	!

icon


	^objeto icon!

objeto
	"Private - Answer the value of the receiver's ''objeto'' instance variable."

	^objeto!

objeto: anObject
	"Private - Set the value of the receiver's ''objeto'' instance variable to the argument, anObject."

	objeto := anObject! !
!ObjectTreeNode categoriesFor: #descripcion!accessing!private! !
!ObjectTreeNode categoriesFor: #descripcion:!accessing!private! !
!ObjectTreeNode categoriesFor: #displayOn:!*-unclassified!public! !
!ObjectTreeNode categoriesFor: #icon!*-unclassified!public! !
!ObjectTreeNode categoriesFor: #objeto!accessing!private! !
!ObjectTreeNode categoriesFor: #objeto:!accessing!private! !



ObjectTreeModel comment: ''!

ObjectTreeModel guid: (GUID fromString: '{26AF8D80-AD4B-11D6-B8E2-000021FB21B2}')!

!ObjectTreeModel categoriesForClass!Unclassified! !
!ObjectTreeModel methodsFor!

getChildrensFor: anObjectTreeNode

	| instVarNames anObject |
	anObject := anObjectTreeNode objeto.

	
	instVarNames := OrderedCollection withAll:  anObject class allInstVarNames. 
	^self wrapCollection: ((1 to: anObject class instSize ) collect:[:index | 
						anObject instVarAt: index] ) , 
	 (( 1  to: anObject basicSize ) collect:[:index |  instVarNames add: index . anObject basicAt: index]) 
		descripciones: instVarNames.
!

hasChildrenFor: anObject


	^anObject objeto  class instSize > 0 or:[ anObject objeto basicSize >0]!

withRoots: aCollection
	"Private - Initialize the receiver with the roots in aCollection"

	"Deliberately omit super initialize"
	getChildrenBlock := [:anObject | self getChildrensFor: anObject] .
	getParentBlock := Message selector: #padre.
	hasChildrenBlock := [:anObject | self hasChildrenFor: anObject  ].
	self basicRoots: (self wrapCollection: aCollection descripciones: (1 to: aCollection basicSize)).!

wrap: anObject descripcion: aString


	^ObjectTreeNode new descripcion: aString displayString  ; objeto: anObject!

wrapCollection: aCollection  descripciones: descripciones 


	|answer|
	answer := Array  new: aCollection basicSize.
	1 to: aCollection basicSize do: [ :i | answer at: i put: (self wrap: (aCollection basicAt: i)  descripcion: (descripciones at: i)) ].
	^answer! !
!ObjectTreeModel categoriesFor: #getChildrensFor:!*-unclassified!public! !
!ObjectTreeModel categoriesFor: #hasChildrenFor:!*-unclassified!public! !
!ObjectTreeModel categoriesFor: #withRoots:!initializing!private! !
!ObjectTreeModel categoriesFor: #wrap:descripcion:!*-unclassified!public! !
!ObjectTreeModel categoriesFor: #wrapCollection:descripciones:!*-unclassified!public! !



ObjectTreeModelPresenter comment: ''!

ObjectTreeModelPresenter guid: (GUID fromString: '{26AF8D82-AD4B-11D6-B8E2-000021FB21B2}')!

!ObjectTreeModelPresenter categoriesForClass!Unclassified! !
!ObjectTreeModelPresenter methodsFor!

accept


	inspector accept!

createComponents

	super createComponents.
	tree := self add: TreePresenter new name:'tree'.
	inspector  := self add: Inspector new  name:'inspector'.
!

createSchematicWiring


	tree when: #selectionChanged send: #onSelectionChanged to: self.
	inspector when: #inspecteeChanged send: #onInspecteeChanged  to: self!

model: anObject


	super model: anObject.
	
	tree model: (ObjectTreeModel withRoots: (Array with: anObject))!

onInspecteeChanged

	
	tree view refreshContents.
	tree selection: inspector object!

onSelectionChanged


	inspector object: (tree selectionOrNil  isNil ifTrue:[nil] ifFalse:[tree selection objeto])!

queryCommand: query



		(#(spawnWithSelection) identityIncludes: query commandSymbol)
		ifTrue: [ 
			query isEnabled: tree  hasSelection.
			^true].

^super queryCommand: query.!

shellClass

	^ObjectTreeModelShell!

spawnWithSelection


	^self shellClass showOn: tree selection objeto.


! !
!ObjectTreeModelPresenter categoriesFor: #accept!*-unclassified!public! !
!ObjectTreeModelPresenter categoriesFor: #createComponents!*-unclassified!public! !
!ObjectTreeModelPresenter categoriesFor: #createSchematicWiring!*-unclassified!public! !
!ObjectTreeModelPresenter categoriesFor: #model:!*-unclassified!public! !
!ObjectTreeModelPresenter categoriesFor: #onInspecteeChanged!*-unclassified!public! !
!ObjectTreeModelPresenter categoriesFor: #onSelectionChanged!*-unclassified!public! !
!ObjectTreeModelPresenter categoriesFor: #queryCommand:!*-unclassified!public! !
!ObjectTreeModelPresenter categoriesFor: #shellClass!*-unclassified!public! !
!ObjectTreeModelPresenter categoriesFor: #spawnWithSelection!*-unclassified!public! !



ObjectTreeModelShell comment: ''!

ObjectTreeModelShell guid: (GUID fromString: '{26AF8D83-AD4B-11D6-B8E2-000021FB21B2}')!

!ObjectTreeModelShell categoriesForClass!Unclassified! !
!ObjectTreeModelShell methodsFor!

createComponents


	super createComponents.
	objectTreePresenter := self add: ObjectTreeModelPresenter new name: 'objectTree'.
!

model: anObject

	super model: anObject.
	objectTreePresenter model: anObject! !
!ObjectTreeModelShell categoriesFor: #createComponents!*-unclassified!public! !
!ObjectTreeModelShell categoriesFor: #model:!*-unclassified!public! !

 
"Binary Globals"!

"Resources"!

(ResourceIdentifier class: ObjectTreeModelPresenter name: 'Default view') assign: (Object fromBinaryStoreBytes:
#[33 83 84 66 32 48 32 70 2 12 0 1 0 0 0 86 105 101 119 82 101 115 111 117 114 99 101 0 0 0 0 14 1 36 0 83 84 66 82 101 115 111 117 114 99 101 83 84 66 66 121 116 101 65 114 114 97 121 65 99 99 101 115 115 111 114 80 114 111 120 121 0 0 0 0 54 0 9 0 66 121 116 101 65 114 114 97 121 104 18 0 0 33 83 84 66 32 48 32 78 8 12 0 10 0 0 0 83 84 66 86 105 101 119 80 114 111 120 121 0 0 0 0 78 2 13 0 1 0 0 0 83 84 66 67 108 97 115 115 80 114 111 120 121 0 0 0 0 54 0 6 0 83 116 114 105 110 103 7 0 0 0 68 111 108 112 104 105 110 146 0 0 0 13 0 0 0 67 111 110 116 97 105 110 101 114 86 105 101 119 38 0 5 0 65 114 114 97 121 15 0 0 0 0 0 0 0 0 0 0 0 194 0 0 0 2 0 0 0 54 0 12 0 76 97 114 103 101 73 110 116 101 103 101 114 4 0 0 0 0 0 0 68 1 0 2 0 96 0 0 0 0 0 0 0 6 1 11 0 83 121 115 116 101 109 67 111 108 111 114 0 0 0 0 31 0 0 0 0 0 0 0 7 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 6 2 18 0 80 114 111 112 111 114 116 105 111 110 97 108 76 97 121 111 117 116 0 0 0 0 14 2 26 0 83 84 66 73 100 101 110 116 105 116 121 68 105 99 116 105 111 110 97 114 121 80 114 111 120 121 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 11 0 0 0 76 111 111 107 117 112 84 97 98 108 101 194 0 0 0 0 0 0 0 16 0 0 0 90 1 0 0 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 18 0 0 0 73 100 101 110 116 105 116 121 68 105 99 116 105 111 110 97 114 121 194 0 0 0 4 0 0 0 90 0 0 0 0 0 0 0 128 0 0 0 194 0 0 0 15 0 0 0 0 0 0 0 96 0 0 0 194 0 0 0 2 0 0 0 242 0 0 0 4 0 0 0 0 0 0 68 1 0 2 0 224 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 7 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 6 7 12 0 66 111 114 100 101 114 76 97 121 111 117 116 0 0 0 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 90 0 0 0 0 0 0 0 128 0 0 0 194 0 0 0 15 0 0 0 0 0 0 0 224 1 0 0 194 0 0 0 2 0 0 0 242 0 0 0 4 0 0 0 0 0 0 68 1 0 2 0 64 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 7 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 50 1 0 0 0 0 0 0 14 2 18 0 83 84 66 67 111 108 108 101 99 116 105 111 110 80 114 111 120 121 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 10 0 0 0 68 105 99 116 105 111 110 97 114 121 194 0 0 0 3 0 0 0 6 2 11 0 65 115 115 111 99 105 97 116 105 111 110 0 0 0 0 90 0 0 0 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 8 0 0 0 83 112 108 105 116 116 101 114 194 0 0 0 12 0 0 0 0 0 0 0 64 2 0 0 194 0 0 0 2 0 0 0 242 0 0 0 4 0 0 0 0 0 0 68 1 0 0 0 0 3 0 0 0 0 0 0 0 0 0 0 0 0 0 0 7 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 6 1 15 0 77 101 115 115 97 103 101 83 101 113 117 101 110 99 101 0 0 0 0 154 2 0 0 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 17 0 0 0 79 114 100 101 114 101 100 67 111 108 108 101 99 116 105 111 110 194 0 0 0 1 0 0 0 6 3 11 0 77 101 115 115 97 103 101 83 101 110 100 0 0 0 0 14 1 14 0 83 84 66 83 121 109 98 111 108 80 114 111 120 121 0 0 0 0 146 0 0 0 16 0 0 0 99 114 101 97 116 101 65 116 58 101 120 116 101 110 116 58 194 0 0 0 2 0 0 0 6 2 5 0 80 111 105 110 116 0 0 0 0 231 0 0 0 1 0 0 0 34 4 0 0 0 0 0 0 7 0 0 0 249 0 0 0 0 3 0 0 6 1 15 0 87 73 78 68 79 87 80 76 65 67 69 77 69 78 84 0 0 0 0 54 0 9 0 66 121 116 101 65 114 114 97 121 44 0 0 0 44 0 0 0 0 0 0 0 1 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 115 0 0 0 0 0 0 0 118 0 0 0 124 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 144 1 0 0 34 4 0 0 0 0 0 0 193 0 0 0 193 0 0 0 0 0 0 0 19 0 0 0 1 0 0 0 226 2 0 0 0 0 0 0 90 0 0 0 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 8 0 0 0 76 105 115 116 86 105 101 119 194 0 0 0 28 0 0 0 0 0 0 0 64 2 0 0 194 0 0 0 2 0 0 0 242 0 0 0 4 0 0 0 77 208 1 68 1 4 0 0 192 4 0 0 70 3 9 0 2 0 0 0 76 105 115 116 77 111 100 101 108 0 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 144 1 0 0 0 0 0 0 6 0 20 0 73 100 101 110 116 105 116 121 83 101 97 114 99 104 80 111 108 105 99 121 0 0 0 0 0 0 0 0 0 0 0 0 7 0 0 0 70 5 4 0 2 0 0 0 77 101 110 117 0 0 0 0 0 0 0 0 16 0 0 0 194 0 0 0 8 0 0 0 70 2 15 0 1 0 0 0 67 111 109 109 97 110 100 77 101 110 117 73 116 101 109 0 0 0 0 1 0 0 0 70 4 18 0 2 0 0 0 67 111 109 109 97 110 100 68 101 115 99 114 105 112 116 105 111 110 0 0 0 0 234 3 0 0 0 0 0 0 146 0 0 0 9 0 0 0 105 110 115 112 101 99 116 73 116 146 0 0 0 8 0 0 0 38 73 110 115 112 101 99 116 1 0 0 0 0 0 0 0 162 5 0 0 0 0 0 0 1 0 0 0 194 5 0 0 0 0 0 0 234 3 0 0 0 0 0 0 146 0 0 0 17 0 0 0 105 110 115 112 101 99 116 82 101 102 101 114 101 110 99 101 115 146 0 0 0 19 0 0 0 73 110 115 112 101 99 116 32 38 82 101 102 101 114 101 110 99 101 115 1 0 0 0 0 0 0 0 70 1 15 0 1 0 0 0 68 105 118 105 100 101 114 77 101 110 117 73 116 101 109 0 0 0 0 1 16 0 0 162 5 0 0 0 0 0 0 1 0 0 0 194 5 0 0 0 0 0 0 234 3 0 0 0 0 0 0 146 0 0 0 11 0 0 0 110 105 108 86 97 114 105 97 98 108 101 146 0 0 0 11 0 0 0 83 101 116 32 116 111 32 38 78 105 108 1 0 0 0 0 0 0 0 98 6 0 0 0 0 0 0 1 16 0 0 162 5 0 0 0 0 0 0 1 0 0 0 194 5 0 0 0 0 0 0 234 3 0 0 0 0 0 0 146 0 0 0 13 0 0 0 98 114 111 119 115 101 67 108 97 115 115 101 115 146 0 0 0 13 0 0 0 38 66 114 111 119 115 101 32 67 108 97 115 115 1 0 0 0 0 0 0 0 98 6 0 0 0 0 0 0 1 16 0 0 162 5 0 0 0 0 0 0 1 0 0 0 194 5 0 0 0 0 0 0 234 3 0 0 0 0 0 0 146 0 0 0 16 0 0 0 114 101 102 114 101 115 104 86 97 114 105 97 98 108 101 115 146 0 0 0 8 0 0 0 82 101 38 102 114 101 115 104 1 0 0 0 0 0 0 0 146 0 0 0 8 0 0 0 38 73 110 115 112 101 99 116 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 242 0 0 0 8 0 0 0 230 211 185 191 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 17 0 0 0 66 97 115 105 99 76 105 115 116 65 98 115 116 114 97 99 116 0 0 0 0 14 2 17 0 83 84 66 83 105 110 103 108 101 116 111 110 80 114 111 120 121 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 16 0 0 0 73 99 111 110 73 109 97 103 101 77 97 110 97 103 101 114 234 3 0 0 0 0 0 0 146 0 0 0 7 0 0 0 99 117 114 114 101 110 116 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 70 12 14 0 4 0 0 0 76 105 115 116 86 105 101 119 67 111 108 117 109 110 0 0 0 0 146 0 0 0 0 0 0 0 223 0 0 0 234 3 0 0 0 0 0 0 146 0 0 0 4 0 0 0 108 101 102 116 176 7 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 16 0 0 0 83 111 114 116 101 100 67 111 108 108 101 99 116 105 111 110 0 0 0 0 0 0 0 0 192 4 0 0 0 0 0 0 16 0 0 0 0 0 0 0 0 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 144 1 0 0 234 3 0 0 0 0 0 0 146 0 0 0 6 0 0 0 114 101 112 111 114 116 1 0 0 0 0 0 0 0 65 8 0 0 98 3 0 0 0 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 2 0 0 0 194 3 0 0 0 0 0 0 240 3 0 0 194 0 0 0 2 0 0 0 34 4 0 0 0 0 0 0 1 0 0 0 1 0 0 0 34 4 0 0 0 0 0 0 231 0 0 0 249 0 0 0 192 4 0 0 194 3 0 0 0 0 0 0 234 3 0 0 0 0 0 0 146 0 0 0 12 0 0 0 99 111 110 116 101 120 116 77 101 110 117 58 194 0 0 0 1 0 0 0 128 5 0 0 192 4 0 0 82 4 0 0 0 0 0 0 114 4 0 0 44 0 0 0 44 0 0 0 0 0 0 0 1 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 0 0 0 0 0 0 0 0 115 0 0 0 124 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 144 1 0 0 160 4 0 0 0 0 0 0 21 0 0 0 3 0 0 0 226 2 0 0 0 0 0 0 90 0 0 0 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 13 0 0 0 82 101 102 101 114 101 110 99 101 86 105 101 119 194 0 0 0 14 0 0 0 0 0 0 0 64 2 0 0 194 0 0 0 2 0 0 0 242 0 0 0 4 0 0 0 0 0 0 68 1 0 2 0 192 9 0 0 0 0 0 0 0 0 0 0 0 0 0 0 7 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 6 2 18 0 82 101 115 111 117 114 99 101 73 100 101 110 116 105 102 105 101 114 0 0 0 0 122 0 0 0 0 0 0 0 146 0 0 0 18 0 0 0 68 101 118 101 108 111 112 109 101 110 116 32 83 121 115 116 101 109 146 0 0 0 18 0 0 0 83 109 97 108 108 116 97 108 107 87 111 114 107 115 112 97 99 101 146 0 0 0 12 0 0 0 68 101 102 97 117 108 116 32 118 105 101 119 0 0 0 0 98 3 0 0 0 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 1 0 0 0 194 3 0 0 0 0 0 0 240 3 0 0 194 0 0 0 2 0 0 0 34 4 0 0 0 0 0 0 237 0 0 0 1 0 0 0 34 4 0 0 0 0 0 0 209 1 0 0 249 0 0 0 192 9 0 0 82 4 0 0 0 0 0 0 114 4 0 0 44 0 0 0 44 0 0 0 0 0 0 0 1 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 118 0 0 0 0 0 0 0 94 1 0 0 124 0 0 0 194 0 0 0 0 0 0 0 160 4 0 0 0 0 0 0 19 0 0 0 5 0 0 0 32 0 0 0 90 1 0 0 0 0 0 0 176 1 0 0 194 0 0 0 4 0 0 0 192 4 0 0 146 0 0 0 13 0 0 0 118 97 114 105 97 98 108 101 110 97 109 101 115 192 9 0 0 146 0 0 0 6 0 0 0 115 111 117 114 99 101 0 0 0 0 98 3 0 0 0 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 1 0 0 0 194 3 0 0 0 0 0 0 240 3 0 0 194 0 0 0 2 0 0 0 34 4 0 0 0 0 0 0 1 0 0 0 1 0 0 0 34 4 0 0 0 0 0 0 189 2 0 0 249 0 0 0 64 2 0 0 82 4 0 0 0 0 0 0 114 4 0 0 44 0 0 0 44 0 0 0 0 0 0 0 1 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 0 0 0 0 0 0 0 0 94 1 0 0 124 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 3 0 0 0 192 4 0 0 0 3 0 0 192 9 0 0 160 4 0 0 0 0 0 0 19 0 0 0 90 1 0 0 0 0 0 0 176 1 0 0 144 1 0 0 0 0 0 0 98 3 0 0 0 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 1 0 0 0 194 3 0 0 0 0 0 0 240 3 0 0 194 0 0 0 2 0 0 0 34 4 0 0 0 0 0 0 1 0 0 0 253 0 0 0 34 4 0 0 0 0 0 0 189 2 0 0 249 0 0 0 224 1 0 0 82 4 0 0 0 0 0 0 114 4 0 0 44 0 0 0 44 0 0 0 0 0 0 0 1 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 0 0 0 0 126 0 0 0 94 1 0 0 250 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 1 0 0 0 64 2 0 0 160 4 0 0 0 0 0 0 19 0 0 0 146 0 0 0 9 0 0 0 105 110 115 112 101 99 116 111 114 90 0 0 0 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 8 0 0 0 84 114 101 101 86 105 101 119 194 0 0 0 25 0 0 0 0 0 0 0 96 0 0 0 194 0 0 0 2 0 0 0 242 0 0 0 4 0 0 0 39 8 1 68 1 4 0 0 224 12 0 0 70 3 9 0 1 0 0 0 84 114 101 101 77 111 100 101 108 0 0 0 0 0 0 0 0 6 3 8 0 84 114 101 101 78 111 100 101 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 90 1 0 0 0 0 0 0 176 1 0 0 144 1 0 0 0 0 0 0 0 0 0 0 7 0 0 0 114 5 0 0 0 0 0 0 0 0 0 0 16 0 0 0 194 0 0 0 1 0 0 0 162 5 0 0 0 0 0 0 1 0 0 0 194 5 0 0 0 0 0 0 234 3 0 0 0 0 0 0 146 0 0 0 18 0 0 0 115 112 97 119 110 87 105 116 104 83 101 108 101 99 116 105 111 110 146 0 0 0 6 0 0 0 38 83 112 97 119 110 1 0 0 0 0 0 0 0 146 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 242 0 0 0 8 0 0 0 118 158 187 191 0 0 0 0 176 7 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 18 0 0 0 73 99 111 110 105 99 76 105 115 116 65 98 115 116 114 97 99 116 224 7 0 0 0 0 0 0 6 4 12 0 66 108 111 99 107 67 108 111 115 117 114 101 0 0 0 0 38 3 13 0 77 101 116 104 111 100 67 111 110 116 101 120 116 1 0 0 0 1 0 0 0 38 5 18 0 67 111 109 112 105 108 101 100 69 120 112 114 101 115 115 105 111 110 3 0 0 0 129 1 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 15 0 0 0 85 110 100 101 102 105 110 101 100 79 98 106 101 99 116 146 0 0 0 4 0 0 0 100 111 73 116 194 0 0 0 2 0 0 0 146 0 0 0 71 0 0 0 91 58 105 32 124 32 105 32 105 115 78 105 108 32 105 102 70 97 108 115 101 58 32 91 32 105 32 111 98 106 101 116 111 32 100 105 115 112 108 97 121 83 116 114 105 110 103 93 13 10 9 32 32 32 105 102 84 114 117 101 58 91 32 39 110 105 108 39 93 32 93 194 0 0 0 1 0 0 0 154 2 0 0 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 14 0 0 0 80 111 111 108 68 105 99 116 105 111 110 97 114 121 144 1 0 0 114 4 0 0 16 0 0 0 251 1 10 0 89 17 222 4 17 158 159 106 31 106 100 105 234 3 0 0 0 0 0 0 146 0 0 0 6 0 0 0 111 98 106 101 116 111 234 3 0 0 0 0 0 0 146 0 0 0 13 0 0 0 100 105 115 112 108 97 121 83 116 114 105 110 103 146 0 0 0 3 0 0 0 110 105 108 0 0 0 0 0 0 0 0 3 0 0 0 11 0 0 0 144 14 0 0 0 0 0 0 0 0 0 0 0 0 0 0 90 1 0 0 0 0 0 0 112 1 0 0 144 1 0 0 17 0 0 0 234 3 0 0 0 0 0 0 146 0 0 0 10 0 0 0 115 109 97 108 108 73 99 111 110 115 98 3 0 0 0 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 2 0 0 0 194 3 0 0 0 0 0 0 240 3 0 0 194 0 0 0 2 0 0 0 34 4 0 0 0 0 0 0 1 0 0 0 1 0 0 0 34 4 0 0 0 0 0 0 189 2 0 0 247 0 0 0 224 12 0 0 194 3 0 0 0 0 0 0 80 9 0 0 194 0 0 0 1 0 0 0 144 13 0 0 224 12 0 0 82 4 0 0 0 0 0 0 114 4 0 0 44 0 0 0 44 0 0 0 0 0 0 0 1 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 0 0 0 0 0 0 0 0 94 1 0 0 123 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 144 1 0 0 160 4 0 0 0 0 0 0 21 0 0 0 146 0 0 0 4 0 0 0 116 114 101 101 0 0 0 0 98 3 0 0 0 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 1 0 0 0 194 3 0 0 0 0 0 0 240 3 0 0 194 0 0 0 2 0 0 0 34 4 0 0 0 0 0 0 11 0 0 0 11 0 0 0 34 4 0 0 0 0 0 0 189 2 0 0 245 1 0 0 96 0 0 0 82 4 0 0 0 0 0 0 114 4 0 0 44 0 0 0 44 0 0 0 0 0 0 0 0 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 5 0 0 0 5 0 0 0 99 1 0 0 255 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 3 0 0 0 224 12 0 0 90 0 0 0 0 0 0 0 16 3 0 0 194 0 0 0 12 0 0 0 0 0 0 0 96 0 0 0 194 0 0 0 2 0 0 0 242 0 0 0 4 0 0 0 0 0 0 68 1 0 0 0 64 17 0 0 0 0 0 0 0 0 0 0 0 0 0 0 7 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 98 3 0 0 0 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 194 0 0 0 1 0 0 0 194 3 0 0 0 0 0 0 240 3 0 0 194 0 0 0 2 0 0 0 34 4 0 0 0 0 0 0 1 0 0 0 247 0 0 0 34 4 0 0 0 0 0 0 189 2 0 0 7 0 0 0 64 17 0 0 82 4 0 0 0 0 0 0 114 4 0 0 44 0 0 0 44 0 0 0 0 0 0 0 1 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 0 0 0 0 123 0 0 0 94 1 0 0 126 0 0 0 154 2 0 0 0 0 0 0 144 3 0 0 144 1 0 0 160 4 0 0 0 0 0 0 19 0 0 0 224 1 0 0 160 4 0 0 0 0 0 0 19 0 0 0 70 5 4 0 3 0 0 0 73 99 111 110 0 0 0 0 0 0 0 0 16 0 0 0 14 2 17 0 83 84 66 83 105 110 103 108 101 116 111 110 80 114 111 120 121 0 0 0 0 78 2 13 0 1 0 0 0 83 84 66 67 108 97 115 115 80 114 111 120 121 0 0 0 0 54 0 6 0 83 116 114 105 110 103 7 0 0 0 68 111 108 112 104 105 110 18 1 0 0 24 0 0 0 73 109 97 103 101 82 101 108 97 116 105 118 101 70 105 108 101 76 111 99 97 116 111 114 14 1 14 0 83 84 66 83 121 109 98 111 108 80 114 111 120 121 0 0 0 0 18 1 0 0 7 0 0 0 99 117 114 114 101 110 116 18 1 0 0 17 0 0 0 67 111 110 116 97 105 110 101 114 86 105 101 119 46 105 99 111 14 2 31 0 83 84 66 69 120 116 101 114 110 97 108 82 101 115 111 117 114 99 101 76 105 98 114 97 114 121 80 114 111 120 121 0 0 0 0 18 1 0 0 16 0 0 0 100 111 108 112 104 105 110 100 114 48 48 52 46 100 108 108 0 0 0 0])!

(ResourceIdentifier class: ObjectTreeModelShell name: 'Default view') assign: (Object fromBinaryStoreBytes:
#[33 83 84 66 32 48 32 70 2 12 0 1 0 0 0 86 105 101 119 82 101 115 111 117 114 99 101 0 0 0 0 14 1 36 0 83 84 66 82 101 115 111 117 114 99 101 83 84 66 66 121 116 101 65 114 114 97 121 65 99 99 101 115 115 111 114 80 114 111 120 121 0 0 0 0 54 0 9 0 66 121 116 101 65 114 114 97 121 118 4 0 0 33 83 84 66 32 48 32 78 8 12 0 10 0 0 0 83 84 66 86 105 101 119 80 114 111 120 121 0 0 0 0 78 2 13 0 1 0 0 0 83 84 66 67 108 97 115 115 80 114 111 120 121 0 0 0 0 54 0 6 0 83 116 114 105 110 103 7 0 0 0 68 111 108 112 104 105 110 146 0 0 0 9 0 0 0 83 104 101 108 108 86 105 101 119 38 0 5 0 65 114 114 97 121 24 0 0 0 0 0 0 0 0 0 0 0 194 0 0 0 2 0 0 0 1 0 158 1 1 0 2 0 96 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 7 2 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 6 7 12 0 66 111 114 100 101 114 76 97 121 111 117 116 0 0 0 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 90 0 0 0 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 13 0 0 0 82 101 102 101 114 101 110 99 101 86 105 101 119 194 0 0 0 14 0 0 0 0 0 0 0 96 0 0 0 194 0 0 0 2 0 0 0 54 0 12 0 76 97 114 103 101 73 110 116 101 103 101 114 4 0 0 0 0 0 0 68 1 0 2 0 16 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 7 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 6 2 18 0 82 101 115 111 117 114 99 101 73 100 101 110 116 105 102 105 101 114 0 0 0 0 122 0 0 0 0 0 0 0 146 0 0 0 10 0 0 0 79 98 106 101 99 116 84 114 101 101 146 0 0 0 24 0 0 0 79 98 106 101 99 116 84 114 101 101 77 111 100 101 108 80 114 101 115 101 110 116 101 114 146 0 0 0 12 0 0 0 68 101 102 97 117 108 116 32 118 105 101 119 0 0 0 0 6 1 15 0 77 101 115 115 97 103 101 83 101 113 117 101 110 99 101 0 0 0 0 14 2 18 0 83 84 66 67 111 108 108 101 99 116 105 111 110 80 114 111 120 121 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 17 0 0 0 79 114 100 101 114 101 100 67 111 108 108 101 99 116 105 111 110 194 0 0 0 1 0 0 0 6 3 11 0 77 101 115 115 97 103 101 83 101 110 100 0 0 0 0 14 1 14 0 83 84 66 83 121 109 98 111 108 80 114 111 120 121 0 0 0 0 146 0 0 0 16 0 0 0 99 114 101 97 116 101 65 116 58 101 120 116 101 110 116 58 194 0 0 0 2 0 0 0 6 2 5 0 80 111 105 110 116 0 0 0 0 1 0 0 0 1 0 0 0 178 2 0 0 0 0 0 0 139 3 0 0 145 1 0 0 16 1 0 0 6 1 15 0 87 73 78 68 79 87 80 76 65 67 69 77 69 78 84 0 0 0 0 54 0 9 0 66 121 116 101 65 114 114 97 121 44 0 0 0 44 0 0 0 0 0 0 0 1 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 0 0 0 0 0 0 0 0 197 1 0 0 200 0 0 0 194 0 0 0 0 0 0 0 178 2 0 0 0 0 0 0 193 0 0 0 193 0 0 0 0 0 0 0 19 0 0 0 14 2 26 0 83 84 66 73 100 101 110 116 105 116 121 68 105 99 116 105 111 110 97 114 121 80 114 111 120 121 0 0 0 0 122 0 0 0 0 0 0 0 160 0 0 0 146 0 0 0 18 0 0 0 73 100 101 110 116 105 116 121 68 105 99 116 105 111 110 97 114 121 194 0 0 0 2 0 0 0 16 1 0 0 146 0 0 0 10 0 0 0 111 98 106 101 99 116 84 114 101 101 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 226 1 0 0 0 0 0 0 10 2 0 0 0 0 0 0 32 2 0 0 194 0 0 0 2 0 0 0 82 2 0 0 0 0 0 0 128 2 0 0 194 0 0 0 2 0 0 0 178 2 0 0 0 0 0 0 11 0 0 0 11 0 0 0 178 2 0 0 0 0 0 0 155 3 0 0 199 1 0 0 96 0 0 0 82 2 0 0 0 0 0 0 122 2 0 0 0 0 0 0 146 0 0 0 8 0 0 0 109 101 110 117 66 97 114 58 194 0 0 0 1 0 0 0 0 0 0 0 96 0 0 0 226 2 0 0 0 0 0 0 2 3 0 0 44 0 0 0 44 0 0 0 0 0 0 0 0 0 0 0 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 255 5 0 0 0 5 0 0 0 210 1 0 0 232 0 0 0 10 2 0 0 0 0 0 0 32 2 0 0 194 0 0 0 1 0 0 0 16 1 0 0 48 3 0 0 0 0 0 0 19 0 0 0 70 5 4 0 3 0 0 0 73 99 111 110 0 0 0 0 0 0 0 0 16 0 0 0 14 2 17 0 83 84 66 83 105 110 103 108 101 116 111 110 80 114 111 120 121 0 0 0 0 78 2 13 0 1 0 0 0 83 84 66 67 108 97 115 115 80 114 111 120 121 0 0 0 0 54 0 6 0 83 116 114 105 110 103 7 0 0 0 68 111 108 112 104 105 110 18 1 0 0 24 0 0 0 73 109 97 103 101 82 101 108 97 116 105 118 101 70 105 108 101 76 111 99 97 116 111 114 14 1 14 0 83 84 66 83 121 109 98 111 108 80 114 111 120 121 0 0 0 0 18 1 0 0 7 0 0 0 99 117 114 114 101 110 116 18 1 0 0 13 0 0 0 83 104 101 108 108 86 105 101 119 46 105 99 111 14 2 31 0 83 84 66 69 120 116 101 114 110 97 108 82 101 115 111 117 114 99 101 76 105 98 114 97 114 121 80 114 111 120 121 0 0 0 0 18 1 0 0 16 0 0 0 100 111 108 112 104 105 110 100 114 48 48 52 46 100 108 108 0 0 0 0])!

